@@ -18,10 +18,11 @@ This module defines interfaces of ZMI configuration.
 from collections import OrderedDict
 
 from zope.interface import Attribute, Interface
-from zope.schema import Bool, Choice, TextLine
+from zope.schema import Bool, Choice, List, TextLine
 from zope.schema.vocabulary import SimpleTerm, SimpleVocabulary
 
-from myams_js import emerald_core_svg_bundle, emerald_mini_svg_bundle, myams_core_svg_bundle, \
+from myams_js import darkmode_core_svg_bundle, darkmode_full_bundle, darkmode_mini_svg_bundle, \
+    emerald_core_svg_bundle, emerald_full_bundle, emerald_mini_svg_bundle, myams_core_svg_bundle, \
     myams_full_bundle, myams_mini_svg_bundle
 from pyams_file.schema import FileField, ImageField
 from pyams_i18n.schema import I18nTextLineField
@@ -36,13 +37,19 @@ MYAMS_BUNDLES = OrderedDict((
     ('full', (myams_full_bundle, _("MyAMS full bundle"))),
     ('mini+svg', (myams_mini_svg_bundle, _("MyAMS mini bundle (with SVG icons)"))),
     ('core+svg', (myams_core_svg_bundle, _("MyAMS core bundle (with SVG icons)"))),
+    ('emerald', (emerald_full_bundle, _("Emerald full bundle"))),
     ('emerald-mini', (emerald_mini_svg_bundle, _("Emerald mini bundle (with SVG icons)"))),
-    ('emerald-core', (emerald_core_svg_bundle, _("Emerald core bundle (with SVG icons)")))
+    ('emerald-core', (emerald_core_svg_bundle, _("Emerald core bundle (with SVG icons)"))),
+    ('darkmode', (darkmode_full_bundle, _("Dark mode full bundle"))),
+    ('darkmode-mini', (darkmode_mini_svg_bundle, _("Dark mode mini bundle (with SVG icons)"))),
+    ('darkmode-core', (darkmode_core_svg_bundle, _("Dark mode core bundle (with SVG icons)")))
 ))
 
 MYAMS_BUNDLES_VOCABULARY = SimpleVocabulary(
     [SimpleTerm(k, title=v[1]) for k, v in MYAMS_BUNDLES.items()])
 
+USER_BUNDLES_VOCABULARY = 'pyams_zmi.profile.bundles'
+
 
 class IZMIConfiguration(Interface):
     """Static management configuration interface"""
@@ -85,6 +92,18 @@ class IZMIConfiguration(Interface):
                           vocabulary=MYAMS_BUNDLES_VOCABULARY,
                           default='full')
 
+    user_bundle_selection = Bool(title=_("Allow bundle selection from user profile"),
+                                 description=_("If 'yes', bundle and theme selections "
+                                               "will be available from user profile"),
+                                 required=True,
+                                 default=False)
+
+    user_bundles = List(title=_("User selected bundles"),
+                        description=_("List of bundles which can be selected from "
+                                      "user profile"),
+                        value_type=Choice(vocabulary=MYAMS_BUNDLES_VOCABULARY),
+                        required=False)
+
     favicon = ImageField(title=_("Icon"),
                          description=_("Favorites icon"),
                          required=False)
