@@ -49,7 +49,7 @@ def get_table_id(table, context=None):
     """Table ID getter"""
     if context is None:
         context = table.context
-    return '{}_{}'.format(table.prefix, ICacheKeyValue(context))
+    return f'{table.prefix}_{ICacheKeyValue(context)}'
 
 
 def get_column_sort(column, ignored=None):  # pylint: disable=unused-argument
@@ -64,7 +64,7 @@ def get_column_type(column, ignored=None):  # pylint: disable=unused-argument
 
 def get_row_id(table, element, context=None):
     """Row ID getter"""
-    return '{}::{}'.format(get_table_id(table, context), ICacheKeyValue(element))
+    return f'{table.id}::{ICacheKeyValue(element)}'
 
 
 def get_row_name(element):
@@ -91,16 +91,18 @@ def get_attributes(table, element, source, column=None):
     for key, value in attrs.items():
         checked_value = check_attribute(value, source, column)
         if checked_value is not None:
-            result += " {}='{}'".format(key, checked_value)
+            result += f" {key}='{checked_value}'"
     return result
 
 
 def get_data_attributes(element):
     """Get object data attributes"""
     data = IObjectData(element, None)
-    if data is not None:
-        return ' '.join(("data-{}='{}'".format(k, v if isinstance(v, str) else json.dumps(v))
-                         for k, v in data.object_data.items()))  # pylint: disable=no-member
+    if data and data.object_data:
+        return ' '.join((
+            f"data-{k}='{v if isinstance(v, str) else json.dumps(v)}'"
+            for k, v in data.object_data.items()
+        ))
     return ''
 
 
@@ -174,30 +176,27 @@ class Table(ObjectDataManagerMixin, BaseTable):
         klass = self.css_classes.get('tr.selected')
         if callable(klass):
             klass = klass(*row)
-        if klass and css_class:
-            klass = '{} {}'.format(klass, css_class)
-        else:
-            klass = css_class or ''
-        return klass
+        return f"{css_class if css_class else ''} {klass if klass else ''}".strip()
 
     def render_table(self):
         return super().render_table() \
-            .replace('<table', '<table {}'.format(get_attributes(self, 'table', self))) \
-            .replace('<table', '<table {}'.format(get_data_attributes(self)))
+            .replace('<table', f"<table {get_attributes(self, 'table', self)}") \
+            .replace('<table', f"<table {get_data_attributes(self)}")
 
     def render_row(self, row, css_class=None):
         css_class = self.get_selected_row_class(row[0], css_class)
         return super().render_row(row, css_class) \
-            .replace('<tr', '<tr {}'.format(get_attributes(self, 'tr', row[0][0])))
+            .replace('<tr', f"<tr {get_attributes(self, 'tr', row[0][0])}")
 
     def render_head_cell(self, column):
         return super().render_head_cell(column) \
-            .replace('<th', '<th {}'.format(get_attributes(self, 'th', column))) \
-            .replace('<th', '<th {}'.format(get_data_attributes(column)))
+            .replace('<th', f"<th {get_attributes(self, 'th', column)}") \
+            .replace('<th', f"<th {get_data_attributes(column)}")
 
     def render_cell(self, item, column, colspan=0):
         return super().render_cell(item, column, colspan) \
-            .replace('<td', '<td {}'.format(get_attributes(self, 'td', item, column)))
+            .replace('<td', f"<td {self.get_css_class('td', None, item, column)}") \
+            .replace('<td', f"<td {get_attributes(self, 'td', item, column)}")
 
 
 class InnerTableMixin:
@@ -290,13 +289,24 @@ class ReorderColumn(Column):
     """Reorder column"""
 
     weight = 0
+    sortable = 'false'
 
     css_classes = {
         'th': 'reorder action',
-        'td': 'action'
+        'td': 'sorter action mouse-move'
     }
 
+    permission = None
+
+    def has_permission(self, item):
+        """Column permission test"""
+        if not self.permission:
+            return True
+        return self.request.has_permission(self.permission, context=item)
+
     def render_cell(self, item):
+        if not self.has_permission(item):
+            return ''
         return '<i class="fas fa-arrows-alt-v"></i>'
 
 
